quantizationtools.Heuristic
===========================

.. abjad-lineage:: abjad.tools.quantizationtools.Heuristic.Heuristic.Heuristic

.. autoclass:: abjad.tools.quantizationtools.Heuristic.Heuristic.Heuristic
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.Heuristic.Heuristic.Heuristic.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.Heuristic.Heuristic.Heuristic.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Heuristic.Heuristic.Heuristic.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Heuristic.Heuristic.Heuristic.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Heuristic.Heuristic.Heuristic.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Heuristic.Heuristic.Heuristic.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Heuristic.Heuristic.Heuristic.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Heuristic.Heuristic.Heuristic.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.Heuristic.Heuristic.Heuristic.__repr__
   :noindex:
